#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-zip
version:              1.1.3
visibility:           public
id:                   hslua-module-zip-1.1.3-IYWLLkRQxga22TAqFTgQGX
key:                  hslua-module-zip-1.1.3-IYWLLkRQxga22TAqFTgQGX
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  6a12621aaffd74ac875a4ff8ef466b24
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.1.3-IYWLLkRQxga22TAqFTgQGX
depends:
    base-4.18.2.1 bytestring-0.11.5.3 filepath-1.4.300.1
    hslua-core-2.3.2-Lg15ARpnorIAwUIHmZm9Pq
    hslua-list-1.1.4-5nvk2zOmIdY17vH9HSU207
    hslua-marshalling-2.3.1-7aPIy1uxKBQLW5vFb8qPx0
    hslua-packaging-2.3.1-KwwbWE9AKziFW25J7udfon
    hslua-typing-0.1.1-CxbY5GD44jIPnolDqjUuu text-2.0.2 time-1.12.2
    zip-archive-0.4.3.2-CcuVGPSWWXM8iklgLryjzF

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

